import { defineNuxtConfig } from 'nuxt/config';

const description = 'I am a MSCA Research Fellow at the University of Padova working on educational videogames, but I also do other things.';

// https://v3.nuxtjs.org/api/configuration/nuxt.config
export default defineNuxtConfig({
    app: {
        head: {
            htmlAttrs: {
                lang: 'en'
            },
            noscript: [
                { children: `<div class="noscript">
                        <center>Hi.</center>
                        First of all: I am <strong>genuinely</strong> interested to know why you disabled JavaScript
                        so <a href="/contact">please send me an e-mail</a> — no judgement.<br />
                        Second: yes, I hate it too, but in this day and age JavaScript is kinda ubiquitous so I caved in.
                        I am still making an effort but this site may look a bit weird and hardly usable without JS. Sorry…
                    <noscript><p><img src="https://merida.morpheu5.net/balmyogre?idsite=1&amp;rec=1" style="border:0;" alt="" /></p></noscript>
                    </div>`
                },
            ],
            meta: [
                { charset: 'utf-8' },
                { property: 'author', content: 'Andrea Franceschini' },
                { property: 'description', content: description },
                { property: 'DC.Creator', content: 'Andrea Franceschini' },
                { property: 'DC.Description', content: description },
                { property: 'DC.Rights', content: 'CC BY-NC-SA 4.0' },

                { property: 'twitter:site', content: '@morpheu5' },
                { property: 'twitter:creator', content: '@morpheu5' },
                { property: 'twitter:description', content: description },
                { property: 'twitter:card', content: 'summary_large_image' },
                { property: 'twitter:image:src', content: 'https://andreafranceschini.org/images/colopic.jpg' },
                { property: 'twitter:domain', content: 'https://andreafranceschini.org' },

                { property: 'og:type', content: 'website' },
                { property: 'og:image', content: 'https://andreafranceschini.org/images/colopic.jpg' },
                { property: 'og:description', content: description },

                { property: 'robots', content: 'All' },
            ],
            link: [
                { rel: 'icon', type: 'image/svg+xml', href: '/images/favicon.svg' },
                { rel: 'icon', type: 'image/png', href: '/images/favicon.png' }
            ]
        },
    },
    css: [
        "~/assets/css/tailwind.css",
        '@fortawesome/fontawesome-svg-core/styles.css',
    ],
    build: {
        analyze: true,
        transpile: [
            'three'
        ],
    },
    modules: [
        '@nuxtjs/tailwindcss',
        '@nuxtjs/google-fonts',
        // ['@pinia/nuxt', { autoImports: ['defineStore'] }],
        '@pinia/nuxt',
        '@pinia-plugin-persistedstate/nuxt',
    ],
    components: true,
    telemetry: false,
    ssr: true,
    sourcemap: process.dev || false,
    typescript: {
        shim: false,
        typeCheck: true,
        strict: true,
    },
    googleFonts: {
        families: {
            Oswald: {
                wght: [400, 600],
            },
            "Open Sans": {
                wght: [400, 700],
            },
        },
        subsets: 'greek',
        download: true,
        // overwriting: true,
    },
    postcss: {
        // map: process.dev || false,
        plugins: {
            'postcss-import': {},
            'postcss-mixins': {},
            'tailwindcss/nesting': {},
            'tailwindcss': {},
            'autoprefixer': {},
            'postcss-preset-env': {},
            'cssnano': {},
        },
    },

})
