const defaultTheme = require('tailwindcss/defaultTheme');

const headerFont = {
    fontFamily: 'Oswald',
    fontWeight: '400',
};

module.exports = {
    content: [
        './assets/**/*.{vue,js,css}',
        './components/**/*.{vue,js}',
        './layouts/**/*.vue',
        './pages/**/*.vue',
        './plugins/**/*.{js,ts}',
        // './nuxt.config.{js,ts}',
    ],
    theme: {
        extend: {
            fontFamily: {
                sans: 'Open Sans'
            },
            typography: theme => ({
                DEFAULT: {
                    css: {
                        h1: { ...headerFont, fontSize: defaultTheme.fontSize['4xl'], lineHeight: '0.7778em' },
                        h2: { ...headerFont, fontSize: defaultTheme.fontSize['3xl'], lineHeight: '0.7778em' },
                        h3: { ...headerFont, fontSize: defaultTheme.fontSize['2xl'], lineHeight: '0.9333em' },
                        h4: { ...headerFont, fontSize: defaultTheme.fontSize[ 'xl'], lineHeight: '1.1667em' },
                        a: {
                            textDecoration: 'none',
                            color: theme('colors.sky.600'),
                        }
                    }
                }
            }),
            screens: {
                print: {raw: 'print'},
            }
        },
    },
    plugins: [
        require('@tailwindcss/typography'),
        require('daisyui'),
        require('@tailwindcss/aspect-ratio'),
    ],
    daisyui: {
        utils: false,
        logs: false,
        themes: [
            {
                lofi: {
                    ...require("daisyui/src/theming/themes")["[data-theme=lofi]"],
                    primary: 'white',
                    info: '#0284c7',
                    success: '#4e9a06',
                    error: '#cc0000',
                    'base-100': 'black',
                    "--rounded-badge": "1rem",
                    "--animation-input": "0.1s",
                }
            }
        ]
    }
}
